#!/bin/bash

# 获取当前脚本所在的目录
script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)

# 用户输入进程ID
read -p "请输入进程ID: " pid

# 用户输入可选参数host，提供默认值
read -p "请输入主机地址和端口号（格式：IP 端口，默认为 127.0.0.1 3658）: " host
host=${host:-"127.0.0.1 3658"}

# 检查当前目录下是否存在jattach文件
if [[ ! -e "$script_dir/jattach" ]]; then
  # 查找以jattach-linux开头的tgz压缩包
  jattach_tgz=$(find "$script_dir" -maxdepth 1 -type f -name "jattach-linux-*.tgz")

  if [[ -z "$jattach_tgz" ]]; then
    echo "当前目录下未找到名为jattach的文件或符合条件的jattach-linux-*.tgz压缩包。"
    exit 1
  fi

  # 判断系统架构
  system_arch=$(uname -m)
  case $system_arch in
    "aarch64"|"arm64")
      arch="arm64"
      jattach_file="jattach-linux-arm64.tgz"
      ;;
    "x86_64"|"amd64")
      arch="x64"
      jattach_file="jattach-linux-x64.tgz"
      ;;
    *)
      echo "当前系统架构不支持自动解压jattach工具。"
      exit 1
  esac

  # 检查对应的jattach压缩包是否存在
  if [[ ! -f "$script_dir/$jattach_file" ]]; then
    echo "当前目录下未找到与系统架构匹配的$jattach_file压缩包。"
    exit 1
  fi

  # 解压缩对应架构的jattach工具到当前脚本目录，并使用绝对路径
  tar -xzvf "$script_dir/$jattach_file" -C "$script_dir"

  # 检查解压后jattach是否成功生成
  if [[ ! -e "$script_dir/jattach" ]]; then
    echo "解压失败或未能在当前目录找到解压后的jattach文件。"
    exit 1
  fi
fi

# 使用jattach命令加载arthas-agent.jar，使用绝对路径
"$script_dir/jattach" $pid load instrument false "$script_dir/arthas-agent.jar" && \

# 运行arthas客户端，同样使用绝对路径
java -jar "$script_dir/arthas-client.jar" $host
